[CMake] Support for Intel Visual Fortran 2013 Beta

Zaheer Chothia zaheer.chothia at gmail.com
Fri Jun 1 18:47:20 EDT 2012


Hello,

Visual Studio fails to load the project files (.vfproj) generated by CMake 2.8.8
when using the Intel Visual Fortran 2013 Beta [1]:

    "The selected project was created by a later version of Intel(R)
Visual Fortran.
     It cannot be loaded with this version."

Projects generated by the wizard within Visual Studio have the version set to
11.0, as was the case with Intel Fortran 11.x and 12.x.  This issue is easy to
diagnose (see patch following this mail) and I have tested that it works with:

    Microsoft Visual Studio 10.0.40219.1
    Intel Visual Fortran 13.0.0.041 Beta Build 20120425

(I am posting this mostly for others who may be searching for the
error message above.)

--Zaheer

[1]: http://software.intel.com/en-us/forums/showthread.php?t=104792

--- a/Source/cmLocalVisualStudio7Generator.cxx
+++ b/Source/cmLocalVisualStudio7Generator.cxx
@@ -1933,9 +1933,10 @@ cmLocalVisualStudio7Generator
   vskey += "\\Packages\\" CM_INTEL_PLUGIN_GUID ";ProductVersion";
   cmSystemTools::ReadRegistryValue(vskey.c_str(), intelVersion,
                                    cmSystemTools::KeyWOW64_32);
-  if (intelVersion.find("12") == 0 || (intelVersion.find("11") == 0))
+  if (intelVersion.find("13") == 0 || intelVersion.find("12") == 0 ||
+      intelVersion.find("11") == 0)
     {
     // Version 11.x and 12.x actually use 11.0 in project files!
     intelVersion = "11.0" ;
     }
   else if(intelVersion.find("10") == 0)
@@ -1933,9 +1933,10 @@ cmLocalVisualStudio7Generator
     {
-    // Version 11.x and 12.x actually use 11.0 in project files!
+    // Version 11.x, 12.x and 13.x actually use 11.0 in project files!
     intelVersion = "11.0" ;
     }


More information about the CMake mailing list